"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeSafeAreaContext = require("react-native-safe-area-context");

var _dateformat = _interopRequireDefault(require("dateformat"));

var _theming = require("../../core/theming");

var _Portal = _interopRequireDefault(require("../Portal/Portal"));

var _Button = _interopRequireDefault(require("../Button"));

var _TextField = _interopRequireDefault(require("../TextField"));

var _Touchable = _interopRequireDefault(require("../Touchable"));

var _DatePickerComponent = _interopRequireDefault(require("./DatePickerComponent"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const MONTHS = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];

const DatePicker = _ref => {
  let {
    style,
    theme: {
      colors
    },
    date = new Date(),
    onDateChange = () => {},
    disabled = false,
    mode = "date",
    format,
    backgroundColorIOS = "rgba(35, 43, 63, 0.9)",
    hitSlop,
    ...props
  } = _ref;
  const [pickerVisible, setPickerVisible] = React.useState(false);
  const textField = React.useRef(null);

  const formatDate = () => {
    if (format) return (0, _dateformat.default)(date, format);

    if (mode === "time") {
      return `${date.toLocaleTimeString()}`;
    }

    if (mode === "datetime") {
      return `${date.toLocaleString()}`;
    }

    return `${MONTHS[date.getMonth()]} ${date.getDate()}, ${date.getFullYear()}`;
  };

  const toggleVisibility = async () => {
    setPickerVisible(!pickerVisible);

    if (textField.current) {
      //@ts-ignore
      textField.current.toggleFocus(); // cannot determine if method exists due to component being wrapped in a withTheme()
    }
  };

  const insets = (0, _reactNativeSafeAreaContext.useSafeAreaInsets)();
  return /*#__PURE__*/React.createElement(_reactNative.View, {
    style: [styles.container, style]
  }, /*#__PURE__*/React.createElement(_Touchable.default, {
    disabled: disabled,
    hitSlop: hitSlop,
    onPress: toggleVisibility
  }, /*#__PURE__*/React.createElement(_reactNative.View, {
    pointerEvents: "none"
  }, /*#__PURE__*/React.createElement(_TextField.default, _extends({}, props, {
    value: formatDate() //@ts-ignore
    ,
    ref: textField // cannot determine if ref is of correct type due to component being wrapped in a withTheme()
    ,
    disabled: disabled
  })))), pickerVisible && /*#__PURE__*/React.createElement(_Portal.default, null, /*#__PURE__*/React.createElement(_reactNative.View, {
    style: [styles.picker, _reactNative.Platform.OS === "ios" && styles.iosPicker, {
      backgroundColor: _reactNative.Platform.OS === "ios" ? backgroundColorIOS : _reactNative.Appearance.getColorScheme() === "light" ? colors.divider : colors.medium
    }]
  }, /*#__PURE__*/React.createElement(_reactNative.View, {
    style: [styles.pickerContainer, {
      paddingTop: 0,
      paddingBottom: 0,
      paddingLeft: insets.left,
      paddingRight: insets.right
    }]
  }, _reactNative.Platform.OS === "ios" && /*#__PURE__*/React.createElement(_reactNative.TouchableWithoutFeedback, {
    onPress: toggleVisibility
  }, /*#__PURE__*/React.createElement(_reactNative.View, {
    style: styles.iosOverlay
  })), /*#__PURE__*/React.createElement(_reactNative.View, {
    style: {
      paddingTop: insets.top,
      paddingBottom: insets.bottom,
      backgroundColor: _reactNative.Appearance.getColorScheme() === "light" ? colors.divider : colors.medium
    }
  }, _reactNative.Platform.OS === "ios" && /*#__PURE__*/React.createElement(_Button.default, {
    type: "text",
    onPress: toggleVisibility,
    style: styles.closeButton,
    labelColor: _reactNative.Appearance.getColorScheme() === "dark" ? colors.divider : colors.primary
  }, "Close"), /*#__PURE__*/React.createElement(_DatePickerComponent.default, {
    value: date,
    mode: mode,
    isVisible: pickerVisible,
    toggleVisibility: toggleVisibility,
    onChange: (_event, data) => {
      _reactNative.Platform.OS === "ios" ? null : toggleVisibility();
      onDateChange(data);
    }
  }))))));
};

const styles = _reactNative.StyleSheet.create({
  container: {
    alignSelf: "stretch"
  },
  picker: {
    position: "absolute",
    bottom: 0,
    left: 0,
    right: 0,
    flexDirection: "row",
    justifyContent: "center"
  },
  iosPicker: {
    top: 0
  },
  pickerContainer: {
    flexDirection: "column",
    width: "100%"
  },
  iosOverlay: {
    flex: 1
  },
  closeButton: {
    alignSelf: "flex-end"
  }
});

var _default = (0, _theming.withTheme)(DatePicker);

exports.default = _default;
//# sourceMappingURL=DatePicker.js.map