"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.SEED_DATA = void 0;

var React = _interopRequireWildcard(require("react"));

var _theming = require("../../core/theming");

var _PickerComponent = _interopRequireDefault(require("./PickerComponent"));

var _componentTypes = require("../../core/component-types");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const Picker = _ref => {
  let {
    options = [],
    placeholder,
    onValueChange: onValueChangeOverride,
    value,
    ...props
  } = _ref;

  const onValueChange = (itemValue, itemIndex) => {
    if (placeholder && itemIndex === 0) {
      return;
    }

    onValueChangeOverride && onValueChangeOverride(itemValue, itemIndex);
  };

  const pickerOptions = placeholder ? [{
    value: placeholder,
    label: placeholder
  }, ...options] : options;
  return /*#__PURE__*/React.createElement(_PickerComponent.default, _extends({}, props, {
    selectedValue: value,
    placeholder: placeholder,
    options: pickerOptions,
    onValueChange: onValueChange
  }));
};

var _default = (0, _theming.withTheme)(Picker);

exports.default = _default;
const SEED_DATA_PROPS = {
  label: {
    group: _componentTypes.GROUPS.data,
    label: "Label",
    description: "The label to be displayed on the picker",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: null,
    editable: true,
    required: true
  },
  placeholder: {
    group: _componentTypes.GROUPS.basic,
    label: "Placeholder",
    description: "The placeholder text of the picker",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "Select an option",
    editable: true,
    required: false
  },
  assistiveText: {
    group: _componentTypes.GROUPS.basic,
    label: "Assistive text",
    description: "Helper text to display below the picker",
    formType: _componentTypes.FORM_TYPES.string,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: null,
    editable: true,
    required: false
  },
  options: {
    group: _componentTypes.GROUPS.data,
    label: "Options",
    description: "Array of picker options. An array of objects containing a label and value.",
    editable: true,
    required: false,
    formType: _componentTypes.FORM_TYPES.array,
    propType: _componentTypes.PROP_TYPES.OBJECT,
    options: [],
    defaultValue: null
  },
  disabled: {
    group: _componentTypes.GROUPS.basic,
    label: "Disabled",
    description: "Whether the picker should be disabled. Will prevent selection and show a greyed out state.",
    formType: _componentTypes.FORM_TYPES.boolean,
    propType: _componentTypes.PROP_TYPES.BOOLEAN,
    defaultValue: false,
    editable: true,
    required: false
  },
  error: {
    group: _componentTypes.GROUPS.data,
    label: "Error",
    description: "Whether the picker should display the error state",
    formType: _componentTypes.FORM_TYPES.boolean,
    propType: _componentTypes.PROP_TYPES.BOOLEAN,
    defaultValue: false,
    editable: true,
    required: false
  },
  leftIconName: {
    group: _componentTypes.GROUPS.basic,
    label: "Left icon name",
    description: "The icon to display on the left",
    formType: _componentTypes.FORM_TYPES.icon,
    propType: _componentTypes.PROP_TYPES.ASSET,
    defaultValue: null,
    editable: true,
    required: false
  },
  leftIconMode: {
    group: _componentTypes.GROUPS.basic,
    label: "Left icon mode",
    description: "The mode of the icon to display on the left. 'inset' or 'outset'.",
    formType: _componentTypes.FORM_TYPES.flatArray,
    propType: _componentTypes.PROP_TYPES.STRING,
    defaultValue: "inset",
    options: ["inset", "outset"],
    editable: true,
    required: true
  },
  rightIconName: {
    group: _componentTypes.GROUPS.basic,
    label: "Right icon name",
    description: "The icon to display on the right",
    formType: _componentTypes.FORM_TYPES.icon,
    propType: _componentTypes.PROP_TYPES.ASSET,
    defaultValue: null,
    editable: true,
    required: false
  },
  fieldName: { ..._componentTypes.FIELD_NAME,
    defaultValue: "pickerValue"
  }
};
const SEED_DATA = [{
  name: "Picker - Solid",
  tag: "Picker",
  description: "A picker with a solid border",
  category: _componentTypes.COMPONENT_TYPES.field,
  preview_image_url: "{CLOUDINARY_URL}/Picker.png",
  supports_list_render: false,
  props: { ...SEED_DATA_PROPS,
    type: {
      group: _componentTypes.GROUPS.uncategorized,
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "solid",
      editable: false,
      required: false
    }
  },
  layout: {}
}, {
  name: "Picker - Underline",
  tag: "Picker",
  description: "A picker with an underline",
  category: _componentTypes.COMPONENT_TYPES.field,
  preview_image_url: "{CLOUDINARY_URL}/Picker.png",
  supports_list_render: false,
  props: { ...SEED_DATA_PROPS,
    type: {
      group: _componentTypes.GROUPS.uncategorized,
      formType: _componentTypes.FORM_TYPES.string,
      propType: _componentTypes.PROP_TYPES.STRING,
      defaultValue: "underline",
      editable: false,
      required: false
    }
  },
  layout: {}
}];
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=Picker.js.map