"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.SEED_DATA = void 0;

var React = _interopRequireWildcard(require("react"));

var _slider = _interopRequireDefault(require("@react-native-community/slider"));

var _theming = require("../core/theming");

var _componentTypes = require("../core/component-types");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const Slider = _ref => {
  let {
    style = {
      height: 4
    },
    value,
    minimumTrackTintColor = "light",
    maximumTrackTintColor = "primary",
    thumbTintColor = "primary",
    disabledThumbTintColor = "strong",
    minimumValue = 0,
    maximumValue = 10,
    step = 1,
    theme,
    disabled = false,
    onValueChange = () => {},
    ...props
  } = _ref;
  const [internalValue, setInternalValue] = React.useState(0);
  return /*#__PURE__*/React.createElement(_slider.default, _extends({}, props, {
    disabled: disabled,
    value: disabled ? 0 : value || internalValue,
    minimumValue: minimumValue,
    maximumValue: maximumValue,
    minimumTrackTintColor: theme.colors[minimumTrackTintColor],
    maximumTrackTintColor: theme.colors[maximumTrackTintColor],
    thumbTintColor: disabled && disabledThumbTintColor ? theme.colors[disabledThumbTintColor] : theme.colors[thumbTintColor],
    onValueChange: newValue => {
      onValueChange(newValue);
      setInternalValue(newValue);
    },
    style: disabled ? [style, {
      opacity: 0.6
    }] : style,
    step: step
  }));
};

var _default = (0, _theming.withTheme)(Slider);

exports.default = _default;
const SEED_DATA = {
  name: "Slider",
  tag: "Slider",
  description: "A component used to set a value in a range",
  category: _componentTypes.COMPONENT_TYPES.input,
  preview_image_url: "{CLOUDINARY_URL}/Control_Slider.png",
  supports_list_render: false,
  props: {
    disabled: {
      group: _componentTypes.GROUPS.data,
      label: "Disabled",
      description: "Whether the slider is disabled",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.boolean,
      defaultValue: null
    },
    maximumValue: {
      group: _componentTypes.GROUPS.basic,
      label: "Maximum value",
      description: "The maximum value of the slider",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.number,
      min: 0,
      max: 1000000,
      step: 1,
      precision: 0,
      defaultValue: 10
    },
    minimumValue: {
      group: _componentTypes.GROUPS.basic,
      label: "Minimum value",
      description: "The minimum value of the slider",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.number,
      min: -1000000,
      max: 1000000,
      step: 1,
      precision: 0,
      defaultValue: 0
    },
    step: {
      group: _componentTypes.GROUPS.basic,
      label: "Step",
      description: "The amount the value should change per step",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.number,
      min: 0,
      max: 100,
      step: 0.01,
      precision: 2,
      defaultValue: null
    },
    fieldName: { ..._componentTypes.FIELD_NAME,
      defaultValue: "sliderValue",
      handlerPropName: "onValueChange"
    },
    maximumTrackTintColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Maximum Color",
      description: "Color of the track from the right of the thumb",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      defaultValue: "primary"
    },
    minimumTrackTintColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Minimum Color",
      description: "Color of the track from the left of the thumb",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      defaultValue: "light"
    },
    thumbTintColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Thumb Tint Color",
      description: "Color of the thumb",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      defaultValue: "primary"
    },
    disabledThumbTintColor: {
      group: _componentTypes.GROUPS.basic,
      label: "Disabled Thumb Tint Color",
      description: "Color of the thumb when the slider is disabled",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.color,
      propType: _componentTypes.PROP_TYPES.THEME,
      defaultValue: "strong"
    },
    thumbTouchSize: {
      group: _componentTypes.GROUPS.advanced,
      label: "Hit Slop",
      description: "The size of the hit slop",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.number,
      min: 0,
      max: 100,
      step: 1,
      precision: 2,
      defaultValue: 4
    },
    trackBorderRadius: {
      group: _componentTypes.GROUPS.basic,
      label: "Track Border Radius",
      description: "The border radius for the track ",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.number,
      min: 0,
      max: 50,
      step: 1,
      precision: 0,
      defaultValue: 4
    },
    thumbBorderRadius: {
      group: _componentTypes.GROUPS.basic,
      label: "Thumb Border Radius",
      description: "The border radius for the thumb",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.number,
      min: 0,
      max: 50,
      step: 1,
      precision: 0,
      defaultValue: 4
    },
    thumbSize: {
      group: _componentTypes.GROUPS.basic,
      label: "Thumb Size",
      description: "Size of the thumb",
      editable: true,
      required: false,
      formType: _componentTypes.FORM_TYPES.number,
      min: 0,
      max: 100,
      step: 1,
      precision: 2,
      defaultValue: 8
    }
  },
  layout: {}
};
exports.SEED_DATA = SEED_DATA;
//# sourceMappingURL=Slider.js.map